==> auto-ui-2.4.55.tgz: package/es/lazy-img/index.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
import React from 'react';
var isSupportLoading = 'loading' in new Image();
var io;
if (window.IntersectionObserver) {
    io = new IntersectionObserver(function (entry) {
        entry.forEach(function (item) {
            if (item.isIntersecting) {
                var ele = item.target;
                // @ts-ignore
                if (!ele.src && ele && ele.dataset && ele.dataset._src) {
                    // @ts-ignore
                    ele.setAttribute('src', ele.dataset._src);
                }
            }
        });
    }, {
        rootMargin: '100px 0px',
    });
}
var LazyImg = function (props) {
    var src = props.src, rest = __rest(props, ["src"]);
    var imgRef = React.useRef(null);
    React.useEffect(function () {
        if (!isSupportLoading && io && imgRef.current) {
            io.observe(imgRef.current);
            return function () {
                io.unobserve(imgRef.current);
            };
        }
    }, []);
    if (isSupportLoading) {
        // @ts-ignore
        return React.createElement("img", __assign({ src: src, loading: "lazy" }, rest));
    }
    if (!window.IntersectionObserver) {
        return React.createElement("img", __assign({ src: src }, rest));
    }
    return React.createElement("img", __assign({ ref: imgRef, "data-_src": src }, rest));
};
export default LazyImg;

==> auto-ui-2.4.63.tgz: package/es/lazy-img/index.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import React from 'react';
var isSupportLoading = 'loading' in new Image();
var io;
if (window.IntersectionObserver) {
    io = new IntersectionObserver(function (entry) {
        entry.forEach(function (item) {
            if (item.isIntersecting) {
                var ele = item.target;
                // @ts-ignore
                if (!ele.src && ele && ele.dataset && ele.dataset._src) {
                    // @ts-ignore
                    ele.setAttribute('src', ele.dataset._src);
                }
            }
        });
    }, {
        rootMargin: '100px 0px',
    });
}
var LazyImg = function (props) {
    var src = props.src, rest = __rest(props, ["src"]);
    var imgRef = React.useRef(null);
    React.useEffect(function () {
        if (!isSupportLoading && io && imgRef.current) {
            io.observe(imgRef.current);
            return function () {
                io.unobserve(imgRef.current);
            };
        }
    }, []);
    if (isSupportLoading) {
        // @ts-ignore
        return React.createElement("img", __assign({ src: src, loading: "lazy" }, rest));
    }
    if (!window.IntersectionObserver) {
        return React.createElement("img", __assign({ src: src }, rest));
    }
    return React.createElement("img", __assign({ ref: imgRef, "data-_src": src }, rest));
};
export default LazyImg;
